@@ -1,5 +1,6 @@
 import os
 import sys
+import uuid
 from types import FunctionType
 
 from werkzeug.exceptions import NotFound
@@ -9,13 +10,16 @@ from .context import AppContext
 from .http import HttpServerError, HttpNotFound, HttpRequest
 from .routes.router import Router
 
+# APP 实例集合
+_APPS = {}
+
 
 class App:
     def __init__(self,
-                 app_id: str,
                  app_root: str,
+                 app_id: str = None,
                  api_prefix='api',
-                 debug_mode=False,
+                 debug=True,
                  append_slash=False,
                  strict_mode=False,
                  api_page_enabled=None,
@@ -26,10 +30,10 @@ class App:
                  ):
         """
 
-        :param app_id: 全局的唯一 id, 用于标识一个APP。可以通过 AppContext.get(id) 获取应用的 Context
         :param app_root: 应用的根目录
+        :param app_id: 全局的唯一 id, 用于标识一个APP。可以通过 AppContext.get(id) 获取应用的 Context，若不指定，则自动生成一个 uuid
         :param api_prefix: API接口URL前缀
-        :param debug_mode: 是否启用调试模式
+        :param debug: 是否启用调试模式
         :param append_slash: 是否在URL末尾使用 / 符号
         :param strict_mode: 是否启用严格模式。在严格模式下，不允许在请求时携带未声明的参数
         :param api_page_enabled: 只否启用接口页面
@@ -38,8 +42,11 @@ class App:
         :param api_page_cache: 是否缓存接口数据
         :param api_page_addition: 接口页面上要展示的接口的附加信息函数，其接收一个 dict 类型的参数 route_info
         """
-        self.id = app_id
-        self.context = AppContext(self.id, app_root, debug_mode, append_slash,
+        self.id = app_id or str(uuid.uuid4())
+
+        _APPS[self.id] = self
+
+        self.context = AppContext(self.id, app_root, debug, append_slash,
                                   strict_mode, api_page_enabled, api_page_name,
                                   api_page_expanded, api_page_cache, api_page_addition)
 
@@ -53,6 +60,10 @@ class App:
             Rule('/%s/<path:entry>%s' % (api_prefix, '/' if append_slash else ''), endpoint='entry_only')
         ])
 
+    def __del__(self):
+        if self.id in _APPS:
+            del _APPS[self.id]
+
     def handle_wsgi_request(self, environ, start_response):
         """
         接收并处理来自 wsgi 的请求
@@ -77,7 +88,7 @@ class App:
         except Exception as e:
             if isinstance(e, NotFound):
                 response = HttpNotFound()
-            elif self.context.DEBUG:
+            elif self.context.debug:
                 raise e
             else:
                 response = HttpServerError()
@@ -115,9 +126,9 @@ class App:
         from restfx.util import helper
         from werkzeug.serving import run_simple
 
-        debug_mode = self.context.DEBUG
+        debug = self.context.debug
 
-        if debug_mode:
+        if debug:
             helper.print_meta('dev-server *DEBUG MODE*')
         else:
             helper.print_meta('dev-server')
@@ -146,25 +157,23 @@ class App:
                 host, port, self.api_prefix, '/' if self.context.append_slash else ''
             ))
 
-        run_simple(host, port, self, use_debugger=debug_mode, use_reloader=debug_mode, threaded=threaded, **kwargs)
+        run_simple(host, port, self, use_debugger=debug, use_reloader=debug, threaded=threaded, **kwargs)
 
-    def collect(self, *global_classes):
+    def collect(self):
         """
         收集路由
-        :param global_classes: 指定路由装饰器上用到的全局类型
         :return:
         """
-        return self.context.collector.collect(self.context.routes_map, *global_classes)
+        return self.context.collector.collect(self.context.routes_map)
 
-    def persist(self, filename: str = '', encoding='utf8', *global_classes):
+    def persist(self, filename: str = '', encoding='utf8'):
         """
         持久化路由信息到文件
         :param filename: 不指定此值时，此函数会返回路由文件内容
         :param encoding:
-        :param global_classes:
         :return:
         """
-        return self.context.collector.persist(self.context.routes_map, filename, encoding, *global_classes)
+        return self.context.collector.persist(self.context.routes_map, filename, encoding)
 
     def set_intercepter(self, intercepter):
         """
@@ -245,10 +254,10 @@ class App:
         :return:
         """
         for route in routes:
-            self.register(*route)
+            self.register_route(*route)
         return self
 
-    def register(self, method: str, path: str, handler: FunctionType):
+    def register_route(self, method: str, path: str, handler: FunctionType):
         """
         手动注册路由
         :param path:
@@ -269,17 +278,6 @@ class App:
         }
         return self
 
-    def register_globals(self, *global_classes):
-        """
-        注册全局类型
-        :type global_classes: class
-        :param global_classes:
-        :return:
-        """
-        for cls in global_classes:
-            self.context.collector.global_classes.append(cls)
-        return self
-
     def register_middleware(self, *middlewares):
         """
         注册中间件，注册的中间件将按顺序执行
@@ -301,9 +299,9 @@ class App:
     @staticmethod
     def get(app_id: str):
         """
-
+        获取指定的应用
         :param app_id:
         :return:
         :rtype: AppContext
         """
-        return AppContext.get(app_id)
+        return _APPS.get(app_id)
